@@ -3,6 +3,8 @@
 #include <QDebug>
 #include <QFile>
 #include <QDir>
+#include <QApplication>
+#include <QClipboard>
 
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus/QDBusConnection>
@@ -143,3 +145,8 @@ void Controller::conversionFinished(int exitCode, QProcess::ExitStatus exitStatu
         emit conversionFailed();
     }
 }
+
+void Controller::copyToClipboard(const QString &url) {
+    QApplication::clipboard()->setText(url);
+    emit alert("Copied to clipboard");
+}
