@@ -83,8 +83,7 @@ void DownloadManager::cancelDownload() {
 
 void DownloadManager::startDownload(const QString &filePath, const QString &url) {
     downloading = true;
-    output.setFileName(filePath);
-    qDebug() << filePath;
+    output.setFileName(filePath + ".partial");
     if (output.exists()) {
         //        qDebug() << "File exists";
         if (!output.open(QIODevice::Append)) {
@@ -146,7 +145,21 @@ void DownloadManager::downloadFinished() {
             emit statusChanged(status);
         }
         else {
-            emit downloadCompleted();
+            QString filename = output.fileName().left(output.fileName().lastIndexOf("."));
+            int num = 1;
+            bool fileSaved = output.rename(filename);
+            while ((!fileSaved) && (num < 10)) {
+                if (num == 1) {
+                    filename = filename.insert(filename.lastIndexOf("."), "(" + QByteArray::number(num) + ")");
+                }
+                else {
+                    filename = filename.replace(filename.lastIndexOf("(" + QByteArray::number(num - 1) + ")"), 3, "(" + QByteArray::number(num) + ")");
+                }
+//                qDebug() << filename;
+                fileSaved = output.rename(filename);
+                num++;
+            }
+            emit downloadCompleted(filename);
         }
     }
 }
