@@ -360,17 +360,10 @@ function storeDownload(video) {
 function removeStoredDownload(filePath) {
     /* Delete the video with matching filePath from the stored downloads */
 
-    var altPath = "";
-    if (filePath.slice(-3) == "mp4") {
-        altPath = filePath.replace(".mp4", ".m4a");
-    }
-    else {
-        altPath = filePath.replace(".m4a", ".mp4");
-    }
     var db = getDatabase();
     var res = "";
     db.transaction(function(tx) {
-                       var rs = tx.executeSql('DELETE FROM savedDownloads WHERE filePath = ? OR filePath = ? OR filePath = ?;', [ filePath, altPath, "" ]);
+                       var rs = tx.executeSql('DELETE FROM savedDownloads WHERE filePath = ? OR filePath = ?;', [ filePath, "" ]);
                        if (rs.rowsAffected > 0) {
                            res = "OK";
                        }
